@@ -3,11 +3,11 @@ acc.samp <- function (n, N, alpha = 0.05, P = 0.99, AQL = 0.01, RQL = 0.02)
     if (RQL - AQL < 4e-08) {
         stop(paste("RQL must be greater than AQL!"))
     }
-    D <- floor((1 - P) * N)
+    D <- N - (N * P)
     m.h <- D
     n.h <- N - D
     ff <- function(k, c, m, n) (alpha) - phyper(c, m, n, k)
-    c <- try(floor(uniroot(ff, interval = c(0, D), k = n, m = m.h, 
+    c <- try(floor(uniroot(ff, interval = c(0, ceiling(D)), k = n, m = m.h, 
         n = n.h)$root), silent = TRUE)
     if (class(c) == "try-error") 
         c <- 0
@@ -24,8 +24,11 @@ acc.samp <- function (n, N, alpha = 0.05, P = 0.99, AQL = 0.01, RQL = 0.02)
     rownames(temp) <- c("acceptance.limit", "lot.size", "confidence", "P", "AQL", 
          "RQL", "sample.size", "prod.risk", "cons.risk")
     colnames(temp) <- ""
-    if (temp[9, ] > alpha) 
+    if (temp[8, ] > alpha) 
         cat("Warning: Desired confidence level not attained!", 
             "\n")
+    if (n == N)
+        cat("Sample size and lot size are the same.  This is just a census!",
+            "\n")
     temp
-}
\ No newline at end of file
+}
